# ISSMOEX package
A package to interact with the [MOEX ISS API](https://iss.moex.com/iss/reference/). 

The aim of the package is to simplify the interaction with ISS MOEX:

1. Facilitation of url requests.   
2. Reduction of downloading time. 

Firstly, most useful url requests are turned into functions with straight forward variables. Hence, the newcomer can easily get information about financial assets traded at MOEX. 

Secondly, the downloading time reduction was achieved by using asynchronous framework. The download time has been improved by 9 times.


The example code, which demonstrates the package capabilities, placed here [here](https://github.com/alexandrettto/issmoex/blob/main/Example%20code.ipynb)
